---
name: Other type of bug report
about: Let us know about an issues that does not fit into any of the other issues
  types
title: ''
labels: ''
assignees: ''

---

**Describe the bug**
A clear and concise description of what the bug is.

**Environment**
- OS: [e.g. Windows/Linux etc...]
- Compiler: revision

**To Reproduce**
Steps to reproduce the behavior:
1. ./vcpkg install xxxx
2. See error
Repro code when

**Expected behavior**
A clear and concise description of what you expected to happen.

**Failure logs**
-(please attached failure logs)

**Additional context**
Add any other context about the problem here.
